@@ -2321,7 +2321,7 @@ void free_object_param(objectptr thisobj, oparamptr thisparam)
 	    for (strptr = plab->string; strptr != NULL; strptr = strptr->nextpart) {
 	       if (strptr->type == PARAM_START) {
 	          if (!strcmp(strptr->data.string, key)) {
-		     unmakeparam(plab, strptr);
+		     unmakeparam(plab, NULL, strptr);
 		     pending = TRUE;
 		     break;
 	          }
@@ -2367,9 +2367,10 @@ stringpart *searchparam(stringpart *tstr)
 /* Remove parameterization from a label string or substring.	*/
 /*--------------------------------------------------------------*/
 
-void unmakeparam(labelptr thislabel, stringpart *thispart)
+void unmakeparam(labelptr thislabel, objinstptr thisinst, stringpart *thispart)
 {
    oparamptr ops;
+   oparamptr testop;
    stringpart *strptr, *lastpart, *endpart, *newstr, *subs;
    char *key;
    
@@ -2388,34 +2389,48 @@ void unmakeparam(labelptr thislabel, stringpart *thispart)
    /* parameter.  The parameter itself will be deleted by a different	*/
    /* method, using free_object_param().				*/
 
-   ops = match_param(topobject, key);
-   subs = ops->parameter.string;
+   ops = (thisinst != NULL) ? match_instance_param(thisinst, key) :
+		match_param(topobject, key);
 
    /* Copy the default parameter into the place we are unparameterizing */
+   /* Promote first to a string type if necessary */
 
-   newstr = NULL;
-   newstr = stringcopy(subs);
+   if (ops->type == XC_STRING) {
+      subs = ops->parameter.string;
+      newstr = NULL;
+      newstr = stringcopy(subs);
 
-   /* Delete the "PARAM_END" off of the copied string and link it into	*/
-   /* the existing string.						*/
-   /* (NOTE:  If parameter is an empty string, there may be nothing	*/
-   /* before PARAM_END. . .)						*/
+      /* Delete the "PARAM_END" off of the copied string and link it 	*/
+      /* into the existing string.					*/
+      /* (NOTE:  If parameter is an empty string, there may be nothing	*/
+      /* before PARAM_END. . .)						*/
 
-   if (newstr->type != PARAM_END) {
-      for (endpart = newstr; endpart->nextpart->type != PARAM_END;
-	   endpart = endpart->nextpart);
-      free(endpart->nextpart);
-      endpart->nextpart = thispart->nextpart;
+      if (newstr->type != PARAM_END) {
+         for (endpart = newstr; endpart->nextpart->type != PARAM_END;
+		endpart = endpart->nextpart);
+         free(endpart->nextpart);
+         endpart->nextpart = thispart->nextpart;
+      }
+      else {
+         endpart = newstr;
+         newstr = newstr->nextpart;
+         free(endpart);
+         endpart = NULL;
+      }
+
+      /* Remove dangling link from instance parameter */
+      /* (If this was a global parameter, it will have no effect) */
+      for (strptr = ops->parameter.string; strptr->type != PARAM_END;
+		strptr = strptr->nextpart);
+      strptr->nextpart = NULL;
    }
    else {
-      endpart = newstr;
-      newstr = newstr->nextpart;
-      free(endpart);
-      endpart = NULL;
+      /* This should not happen */
+      Fprintf(stderr, "Error:  String contains non-string parameter!\n");
+      redrawtext(thislabel);
+      return;
    }
 
-   /* Find the stringpart before the parameter call (if any) */
-
    lastpart = NULL;
    for (strptr = thislabel->string; strptr != NULL && strptr != thispart;
 		strptr = strptr->nextpart) {
@@ -2479,7 +2494,7 @@ void unparameterize(int mode)
       /* Finish search, unlinking any parameter we might be inside */
       for (; tmpptr != NULL; tmpptr = nextstringpart(tmpptr, areawin->topinstance));
 
-      if (lastptr != NULL) unmakeparam(settext, lastptr);
+      if (lastptr != NULL) unmakeparam(settext, areawin->topinstance, lastptr);
    }
    else {
       for (fselect = areawin->selectlist; fselect < areawin->selectlist +
@@ -2489,7 +2504,7 @@ void unparameterize(int mode)
             strptr = settext->string;
             while (strptr != NULL && strptr->type != PARAM_START)
 	       strptr = strptr->nextpart;
-	    if (strptr != NULL) unmakeparam(settext, strptr);
+	    if (strptr != NULL) unmakeparam(settext, areawin->topinstance, strptr);
 	 }
 	 else if (mode == P_POSITION) {
 	    removenumericalp(topobject->plist + (*fselect), P_POSITION_X);
