@@ -2427,7 +2427,8 @@ void composefontlib(short cfont)
       schar->data.string = strdup(character);
       schar->nextpart = NULL;
       label = new_label(xobjs.libtop[FONTLIB], sfont, NORMAL,
-	    (i % 16) * del + del / 2, -(i / 16) * del - del / 2 - 32 /2);
+		(i % 16) * del + del / 2, -(i / 16) * del - del / 2 - 32 /2,
+		(u_char)0);
       label->anchor = NOTLEFT;
       label->color = DEFAULTCOLOR;
    }
